@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "aio" "1.1"
+(define-package "aio" "20251117.644"
   "Async/await for Emacs Lisp."
   '((emacs "26.1"))
   :url "https://github.com/skeeto/emacs-aio"
-  :commit "e0105f8ec8c47c12c0958442d0eaef72c94e8747"
-  :revdesc "1.1-0-ge0105f8ec8c4"
+  :commit "58157e51e7eb7a4b954894ee4182564c507a2f01"
+  :revdesc "58157e51e7eb"
   :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
   :maintainers '(("Christopher Wellons" . "wellons@nullprogram.com")))
