@@ -4,8 +4,8 @@
 
 ;; Author: Christopher Wellons <wellons@nullprogram.com>
 ;; URL: https://github.com/skeeto/emacs-aio
-;; Package-Version: 1.1
-;; Package-Revision: 1.1-0-ge0105f8ec8c4
+;; Package-Version: 20251117.644
+;; Package-Revision: 58157e51e7eb
 ;; Package-Requires: ((emacs "26.1"))
 
 ;;; Commentary:
@@ -127,7 +127,9 @@ returns a promise that will resolve to the function's return
 value, or any uncaught error signal.
 
 See Info node ‘(elisp)Lambda Components’ for a description of
-ARGLIST and BODY."
+ARGLIST and BODY.
+
+\(fn ARGLIST &optional DOCSTRING INTERACTIVE &rest BODY)"
   (declare (indent defun)
            (doc-string 3)
            (debug (&define lambda-list lambda-doc
